import { createRouteRef, createPlugin, createComponentExtension } from '@backstage/core-plugin-api';
import React, { createContext, useContext, useMemo } from 'react';
import { useEntity } from '@backstage/plugin-catalog-react';
import { ANNOTATION_SOURCE_LOCATION } from '@backstage/catalog-model';

const rootRouteRef = createRouteRef({
  id: "backstage-plugin-devcontainers-react"
});

const DEFAULT_DEVCONTAINERS_TAG = "devcontainers-plugin";
const ConfigContext = createContext(null);
function useDevcontainersConfig() {
  const contextValue = useContext(ConfigContext);
  if (contextValue === null) {
    throw new Error(
      `${useDevcontainersConfig.name} is being called outside of a Devcontainers context`
    );
  }
  return contextValue;
}
const DevcontainersProvider$1 = ({ children, config }) => {
  const stableConfig = useMemo(() => {
    var _a;
    return {
      tagName: (_a = config.tagName) != null ? _a : DEFAULT_DEVCONTAINERS_TAG
    };
  }, [config]);
  return /* @__PURE__ */ React.createElement(ConfigContext.Provider, { value: stableConfig }, children);
};

function useDevcontainers() {
  var _a, _b, _c;
  const { tagName } = useDevcontainersConfig();
  const { entity } = useEntity();
  const tags = (_b = (_a = entity.metadata) == null ? void 0 : _a.tags) != null ? _b : [];
  if (!tags.includes(tagName)) {
    return {
      tagName,
      hasUrl: false,
      vsCodeUrl: void 0
    };
  }
  const repoUrl = (_c = entity.metadata.annotations) == null ? void 0 : _c[ANNOTATION_SOURCE_LOCATION];
  if (!repoUrl) {
    return {
      tagName,
      hasUrl: false,
      vsCodeUrl: void 0
    };
  }
  return {
    tagName,
    hasUrl: true,
    vsCodeUrl: serializeVsCodeUrl(repoUrl)
  };
}
function serializeVsCodeUrl(repoUrl) {
  const cleaners = [/^url: */, /\/tree\/main\/?$/];
  const cleanedUrl = cleaners.reduce((str, re) => str.replace(re, ""), repoUrl);
  return `vscode://ms-vscode-remote.remote-containers/cloneInVolume?url=${cleanedUrl}`;
}

const devcontainersPlugin = createPlugin({
  id: "backstage-plugin-devcontainers-react",
  routes: {
    root: rootRouteRef
  }
});
const DevcontainersProvider = devcontainersPlugin.provide(
  createComponentExtension({
    name: "DevcontainersProvider",
    component: {
      lazy: () => import('./index-18ebe194.esm.js').then(
        (m) => m.DevcontainersProvider
      )
    }
  })
);
const ExampleDevcontainersComponent = devcontainersPlugin.provide(
  createComponentExtension({
    name: "ExampleDevcontainersComponent",
    component: {
      lazy: () => import('./index-6ff92bd9.esm.js').then(
        (m) => m.ExampleDevcontainersComponent
      )
    }
  })
);

export { DevcontainersProvider$1 as D, ExampleDevcontainersComponent as E, useDevcontainers as a, DevcontainersProvider as b, devcontainersPlugin as d, useDevcontainersConfig as u };
//# sourceMappingURL=index-f7508b84.esm.js.map
