/// <reference types="react" />
import * as react from 'react';
import * as _backstage_core_plugin_api from '@backstage/core-plugin-api';

type UseDevcontainersResult = Readonly<{
    tagName: string;
} & ({
    /**
     * Indicates whether the current entity component has a devcontainers
     * URL associated with it.
     *
     * This value is set up as a discriminated union for better ergonomics.
     * As long as `hasUrl` is true (and the code has been narrowed with a type
     * guard), `vsCodeUrl` will always be of type string
     */
    hasUrl: false;
    vsCodeUrl: undefined;
} | {
    hasUrl: true;
    vsCodeUrl: string;
})>;
declare function useDevcontainers(): UseDevcontainersResult;

type DevcontainersConfig = Readonly<{
    /**
     * The tag appended by the devcontainers-backend plugin to flag components as
     * having a devcontainers file.
     *
     * By default, the backend and frontend plugins are configured to use the same
     * tag, but if the backend's tag is overridden, it must also be overridden in
     * the frontend config
     */
    tagName?: string;
}>;

declare const devcontainersPlugin: _backstage_core_plugin_api.BackstagePlugin<{
    root: _backstage_core_plugin_api.RouteRef<undefined>;
}, {}, {}>;
/**
 * All public component exports exposed by the plugin.
 */
declare const DevcontainersProvider: ({ children, config }: Readonly<react.PropsWithChildren<{
    config: Readonly<{
        tagName?: string | undefined;
    }>;
}>>) => react.JSX.Element;
declare const ExampleDevcontainersComponent: () => react.JSX.Element;

export { DevcontainersConfig, DevcontainersProvider, ExampleDevcontainersComponent, devcontainersPlugin, useDevcontainers };
